
Content
-------
:'area_left': Gifti file, left hemisphere area data
:'area_right': Gifti file, right hemisphere area data
:'curv_left': Gifti file, left hemisphere curvature data
:'curv_right': Gifti file, right hemisphere curvature data
:'flat_left': Gifti file, left hemisphere flat surface :term:`mesh`
:'flat_right': Gifti file, right hemisphere flat surface :term:`mesh`
:'pial_left': Gifti file, left hemisphere pial surface :term:`mesh`
:'pial_right': Gifti file, right hemisphere pial surface :term:`mesh`
:'infl_left': Gifti file, left hemisphere inflated pial surface :term:`mesh`
:'infl_right': Gifti file, right hemisphere inflated pial surface :term:`mesh`
:'sphere_left': Gifti file, left hemisphere sphere surface :term:`mesh`
:'sphere_right': Gifti file, right hemisphere sphere surface :term:`mesh`
:'sulc_left': Gifti file, left hemisphere sulcal depth data
:'sulc_right': Gifti file, right hemisphere sulcal depth data
:'thick_left': Gifti file, left hemisphere cortical thickness data
:'thick_right': Gifti file, right hemisphere cortical thickness data
:'white_left': Gifti file, left hemisphere white surface :term:`mesh`
:'white_right': Gifti file, right hemisphere white surface :term:`mesh`

See Also
--------
See :func:`~nilearn.datasets.load_fsaverage` and
:func:`~nilearn.datasets.load_fsaverage_data`
to access fsaverage data as :obj:`~nilearn.surface.SurfaceImage`.
